Impossible sounds | The 50/90 Challenge
Description: Another song recorded in a single take, with the Teenage Engineering OP-Z for sounds and the Korg mini kaoss pad 2S for effects (I'm using the "Freeze Looper"). I've been experimenting with the tape track on the OP-Z, and in this song I send the main melody to it on the second part, to add some variability and make it much more interesting. It's a fun effect, and I love how

Skip to main content

# Impossible sounds

- View(active tab)
- Edit

## Impossible sounds

Elesimo

## Post date:

07/05/2020 - 14:48

## Tags:

- op-z
- instrumental

## Demo:

## impossible_sounds.mp3

impossible_sounds.mp3
Download this Demo
Make this song Private

## Liner Notes:

Another song recorded in a single take, with the Teenage Engineering OP-Z for sounds and the Korg mini kaoss pad 2S for effects (I'm using the "Freeze Looper"). I've been experimenting with the tape track on the OP-Z, and in this song I send the main melody to it on the second part, to add some variability and make it much more interesting. It's a fun effect, and I love how the song turned out to be very whimsical!

Again I did some light mastering on Ardour, since the peaks were very high.

Rain samples are from daveincamas on Freesound.

## Lyrics:

N/A

- Add new comment
- Save this song

Please keep your comments respectful, honest, and constructive. Please focus on the song and not the demo.

## Comments

Whimsical for sure - it's a happy melody, and the quivering effect makes it sound like it's laughing. The coolness of the rain samples is very welcome on this hot day!

yeah i like that one. i love your notes its like reading swahili, but slowly getting to understand some words. i like the rain

Like strolling through an 8-bit flower field.

Good melodies, fun use of the sample site!

Good job!

The rain throughout is great,and complements the upbeat music perfectly.

Lots of nice sounds, a bit of blippy 8 bit summer chill out vibe, is the tape track a kind of tape delay thingies?

## Add new comment

Your name Elesimo
Comment *
feed me
To prevent automated spam submissions leave this field empty.